import pytest
from rest_framework.test import APIClient


@pytest.mark.django_db
def test_user_account_creation():
    client = APIClient()
    response = client.post(
        "/register/",
        {"email": "jeckonia@gmail.com", "password": "macy3663"},
        format="json",
    )

    assert response.status_code == 201
    from bunifu_django_auth.models.users import User
    assert User.objects.filter(email="jeckonia@gmail.com").exists()




import pytest
from rest_framework.test import APIClient
from ..factories.users import UserFactory

@pytest.mark.django_db
def test_token_refresh():
    raw_password = "password123"
    user = UserFactory(password=raw_password)
    client = APIClient()
    login_resp = client.post(
        "/login/",
        {"email": user.email, "password": raw_password},
        format="json"
    )

    assert login_resp.status_code == 200
    assert "refresh" in login_resp.data
    assert "access" in login_resp.data

    refresh_token = login_resp.data["refresh"]

    refresh_resp = client.post(
        "/refresh/",
        {"refresh": refresh_token},
        format="json"
    )

    assert refresh_resp.status_code == 200
    assert "access" in refresh_resp.data
    assert refresh_resp.data["access"] != login_resp.data["access"]





from rest_framework.views import APIView
from rest_framework.response import Response
from rest_framework import status, permissions
from ..serializers.logout import LogoutSerializer


class LogoutView(APIView):
    permission_classes = [permissions.IsAuthenticated]

    def post(self, request):
        serializer = LogoutSerializer(data=request.data)
        serializer.is_valid(raise_exception=True)
        serializer.save()
        return Response(
            {"detail": "Successfully logged out."}, status=status.HTTP_200_OK
        )



from django.contrib.auth.models import AbstractUser
from django.db import models
from ..managers.users import UserManager


class User(AbstractUser):
    """
    This user need to be as minimal as possible
    
    The other user related field need to be modified 
    using maybe a profile model not this
    This will allow for the consistency of the user table and wont 
    break between different django applications
    """
    username = None
    email = models.EmailField(unique=True)

    USERNAME_FIELD = "email"
    REQUIRED_FIELDS = []
    
    objects = UserManager()

    def __str__(self):
        return self.email


from django.urls import path
from .views.register import RegisterView
from .views.logout import LogoutView
from rest_framework_simplejwt.views import (
    TokenObtainPairView,
    TokenRefreshView,
)

urlpatterns = [
    path("register/", RegisterView.as_view(), name="register"),
    path("login/", TokenObtainPairView.as_view(), name="token_obtain_pair"),
    path("refresh/", TokenRefreshView.as_view(), name="token_refresh"),
    path("logout/", LogoutView.as_view(), name="logout"),
]
